@@ -4,16 +4,14 @@ Main interface for sso-oidc service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_sso_oidc import (
         Client,
         SSOOIDCClient,
     )
 
-    session = boto3.Session()
-
-    client: SSOOIDCClient = boto3.client("sso-oidc")
-    session_client: SSOOIDCClient = session.client("sso-oidc")
+    session = Session()
+    client: SSOOIDCClient = session.client("sso-oidc")
     ```
 """
 from .client import SSOOIDCClient
