@@ -89,7 +89,7 @@ class SSOOIDCClient(BaseClient):
         clientId: str,
         clientSecret: str,
         grantType: str,
-        deviceCode: str,
+        deviceCode: str = ...,
         code: str = ...,
         refreshToken: str = ...,
         scope: Sequence[str] = ...,
@@ -120,7 +120,7 @@ class SSOOIDCClient(BaseClient):
         self, *, clientName: str, clientType: str, scopes: Sequence[str] = ...
     ) -> RegisterClientResponseTypeDef:
         """
-        Registers a client with Amazon Web Services SSO.
+        Registers a client with AWS SSO.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client/#register_client)
